@@ -7,8 +7,7 @@ A script to submit a Work Requirement.
 from copy import deepcopy
 from datetime import timedelta
 from math import ceil
-from os import chdir
-from os.path import basename, dirname
+from os.path import basename, dirname, relpath
 from typing import Dict, List, Optional
 
 import jsons
@@ -88,6 +87,7 @@ from yd_commands.variables import (
     load_jsonnet_file_with_variable_substitutions,
     load_toml_file_with_variable_substitutions,
     process_variable_substitutions_insitu,
+    resolve_filename,
 )
 from yd_commands.wrapper import ARGS_PARSER, CLIENT, CONFIG_COMMON, main_wrapper
 
@@ -111,6 +111,8 @@ YD_TASK_GROUP_NAME = "YD_TASK_GROUP_NAME"
 YD_TASK_GROUP_NUMBER = "YD_TASK_GROUP_NUMBER"
 YD_TASK_NAME = "YD_TASK_NAME"
 YD_TASK_NUMBER = "YD_TASK_NUMBER"
+YD_NAMESPACE = "YD_NAMESPACE"
+YD_TAG = "YD_TAG"
 
 
 @main_wrapper
@@ -133,14 +135,23 @@ def main():
             "Option '--process-csv-only' is only valid if CSV file(s) specified"
         )
 
+    # Where do we find the data files?
+    # content-path > wr_data_file location > config file location
+    files_directory = (
+        (CONFIG_FILE_DIR if wr_data_file is None else dirname(wr_data_file))
+        if ARGS_PARSER.content_path is None
+        else ARGS_PARSER.content_path
+    )
+
     if wr_data_file is None and csv_files is not None:
-        wr_data = csv_expand_toml_tasks(CONFIG_WR, csv_files[0])
+        wr_data = csv_expand_toml_tasks(CONFIG_WR, csv_files[0], files_directory)
         submit_work_requirement(
-            directory_to_upload_from=CONFIG_FILE_DIR,
+            files_directory=CONFIG_FILE_DIR,
             wr_data=wr_data,
         )
 
     elif wr_data_file is not None:
+        wr_data_file = relpath(wr_data_file)
         print_log(f"Loading Work Requirement data from: '{wr_data_file}'")
 
         # JSON file
@@ -149,9 +160,15 @@ def main():
                 wr_data = load_json_file_with_csv_task_expansion(
                     json_file=wr_data_file,
                     csv_files=csv_files,
+                    files_directory=files_directory,
                 )
             else:
-                wr_data = load_json_file_with_variable_substitutions(wr_data_file)
+                wr_data = load_json_file_with_variable_substitutions(
+                    filename=wr_data_file,
+                    prefix="",
+                    postfix="",
+                    files_directory=files_directory,
+                )
 
         # Jsonnet file
         elif wr_data_file.lower().endswith("jsonnet"):
@@ -161,7 +178,12 @@ def main():
                     csv_files=csv_files,
                 )
             else:
-                wr_data = load_jsonnet_file_with_variable_substitutions(wr_data_file)
+                wr_data = load_jsonnet_file_with_variable_substitutions(
+                    filename=wr_data_file,
+                    prefix="",
+                    postfix="",
+                    files_directory=files_directory,
+                )
 
         # TOML file (undocumented)
         elif wr_data_file.lower().endswith("toml"):
@@ -169,9 +191,12 @@ def main():
                 wr_data = load_toml_file_with_csv_task_expansion(
                     toml_file=wr_data_file,
                     csv_files=csv_files,
+                    files_directory=files_directory,
                 )
             else:
-                wr_data = load_toml_file_with_variable_substitutions(wr_data_file)
+                wr_data = load_toml_file_with_variable_substitutions(
+                    filename=wr_data_file, files_directory=files_directory
+                )
 
         # None of the above
         else:
@@ -179,23 +204,16 @@ def main():
                 f"Work Requirement data file '{wr_data_file}' "
                 "must end with '.json', '.jsonnet', or '.toml'"
             )
+
         validate_properties(wr_data, "Work Requirement JSON")
         submit_work_requirement(
-            directory_to_upload_from=(
-                dirname(wr_data_file)
-                if ARGS_PARSER.content_path is None
-                else ARGS_PARSER.content_path
-            ),
+            files_directory=files_directory,
             wr_data=wr_data,
         )
 
     else:
         submit_work_requirement(
-            directory_to_upload_from=(
-                CONFIG_FILE_DIR
-                if ARGS_PARSER.content_path is None
-                else ARGS_PARSER.content_path
-            ),
+            files_directory=files_directory,
             task_count=CONFIG_WR.task_count,
         )
 
@@ -204,7 +222,7 @@ def main():
 
 
 def submit_work_requirement(
-    directory_to_upload_from: str,
+    files_directory: str,
     wr_data: Optional[Dict] = None,
     task_count: Optional[int] = None,
 ):
@@ -240,17 +258,9 @@ def submit_work_requirement(
 
     # Handle any files that need to be uploaded
     global UPLOADED_FILES
-    UPLOADED_FILES = UploadedFiles(client=CLIENT, wr_name=ID, config=CONFIG_COMMON)
-
-    # Ensure we're in the correct directory for uploads
-    if directory_to_upload_from != "":
-        try:
-            chdir(directory_to_upload_from)
-        except Exception as e:
-            raise Exception(
-                "Unable to switch to content directory"
-                f" '{directory_to_upload_from}': {e}"
-            )
+    UPLOADED_FILES = UploadedFiles(
+        client=CLIENT, wr_name=ID, config=CONFIG_COMMON, files_directory=files_directory
+    )
 
     # Flatten upload paths?
     flatten_upload_paths = check_bool(
@@ -299,6 +309,7 @@ def submit_work_requirement(
                 task_count,
                 work_requirement,
                 flatten_upload_paths=flatten_upload_paths,
+                files_directory=files_directory,
             )
 
         except Exception as e:
@@ -498,6 +509,7 @@ def add_tasks_to_task_group(
     task_count: Optional[int],
     work_requirement: WorkRequirement,
     flatten_upload_paths: bool = False,
+    files_directory: str = "",
 ) -> None:
     """
     Add all the constituent Tasks to the Task Group.
@@ -609,7 +621,9 @@ def add_tasks_to_task_group(
 
             # Task timeout is automatically inherited from the Task Group level
             # unless overridden by the Task
-            task_timeout_minutes = check_float_or_int(task.get(TASK_LEVEL_TIMEOUT, None))
+            task_timeout_minutes = check_float_or_int(
+                task.get(TASK_LEVEL_TIMEOUT, None)
+            )
             task_timeout = (
                 None
                 if task_timeout_minutes is None
@@ -813,7 +827,12 @@ def add_tasks_to_task_group(
                     executable=executable,
                     args=arguments_list,
                     task_data_property=get_task_data_property(
-                        config_wr, wr_data, task_group_data, task, task_name
+                        config_wr,
+                        wr_data,
+                        task_group_data,
+                        task,
+                        task_name,
+                        files_directory,
                     ),
                     env=env,
                     inputs=inputs,
@@ -861,6 +880,7 @@ def get_task_data_property(
     task_group_data: Dict,
     task: Dict,
     task_name: str,
+    files_directory: str = "",
 ) -> Optional[str]:
     """
     Get the 'taskData' property, either using the contents of the file
@@ -887,20 +907,9 @@ def get_task_data_property(
             return task_data_property
 
         if task_data_file_property:
-            # Switch to the directory containing the config file; will use the current
-            # directory if the config file is absent
-            source_directory = (
-                CONFIG_FILE_DIR
-                if ARGS_PARSER.content_path is None or ARGS_PARSER.content_path == ""
-                else ARGS_PARSER.content_path
-            )
-            try:
-                chdir(source_directory)
-            except Exception as e:
-                raise Exception(
-                    f"Unable to switch to content directory '{source_directory}': {e}"
-                )
-            with open(task_data_file_property, "r") as f:
+            with open(
+                resolve_filename(files_directory, task_data_file_property), "r"
+            ) as f:
                 return f.read()
 
 
@@ -1142,6 +1151,8 @@ def create_task(
         env_copy[YD_TASK_GROUP_NAME] = tg_name
         env_copy[YD_TASK_GROUP_NUMBER] = str(tg_number)
         env_copy[YD_WORK_REQUIREMENT_NAME] = ID
+        env_copy[YD_NAMESPACE] = CONFIG_COMMON.namespace
+        env_copy[YD_TAG] = CONFIG_COMMON.name_tag
 
     # Special processing for Bash, Python & PowerShell tasks if the 'executable'
     # property is set. The script is uploaded if this hasn't already been done,
@@ -1208,6 +1219,8 @@ def create_task(
         docker_env_list += ["--env", f"{YD_TASK_GROUP_NAME}={tg_name}"]
         docker_env_list += ["--env", f"{YD_TASK_GROUP_NUMBER}={tg_number}"]
         docker_env_list += ["--env", f"{YD_WORK_REQUIREMENT_NAME}={ID}"]
+        docker_env_list += ["--env", f"{YD_NAMESPACE}={CONFIG_COMMON.namespace}"]
+        docker_env_list += ["--env", f"{YD_TAG}={CONFIG_COMMON.name_tag}"]
 
         if docker_env is not None:
             for key, value in docker_env.items():
